# oneNeuron_pypi
oneNeuron_pypi

# Reference -
[setup.py (dynamics)](https://packaging.python.org/tutorials/packaging-projects/)

![cicd.yml file](https://docs.github.com/en/actions/guides/building-and-testing-python#publishing-to-package-registries)